summaryrefslogtreecommitdiffstats
path: root/include
diff options
context:
space:
mode:
Diffstat (limited to 'include')
-rw-r--r--include/qpdf/QPDFObjectHandle.hh7
1 files changed, 5 insertions, 2 deletions
diff --git a/include/qpdf/QPDFObjectHandle.hh b/include/qpdf/QPDFObjectHandle.hh
index 348aef6b..0a277384 100644
--- a/include/qpdf/QPDFObjectHandle.hh
+++ b/include/qpdf/QPDFObjectHandle.hh
@@ -77,14 +77,14 @@ class DLL_EXPORT QPDFObjectHandle
bool isNumber();
double getNumericValue();
- // Methods for name objects
+ // Methods for name objects; see also name and array objects
std::string getName();
// Methods for string objects
std::string getStringValue();
std::string getUTF8Value();
// Methods for array objects
int getArrayNItems();
QPDFObjectHandle getArrayItem(int n);
@@ -93,6 +93,9 @@ class DLL_EXPORT QPDFObjectHandle
QPDFObjectHandle getKey(std::string const&);
std::set<std::string> getKeys();
+ // Methods for name and array objects
+ bool isOrHasName(std::string const&);
+
// Mutator methods. Use with caution.
// Recursively copy this object, making it direct. Throws an
@@ -77,14 +77,14 @@ class DLL_EXPORT QPDFObjectHandle
std::string getStringValue();
std::string getUTF8Value();
- // Methods for array objects
+ // Methods for array objects; see also name and array objects
int getArrayNItems();
QPDFObjectHandle getArrayItem(int n);